
===========================
TauREx |version| User Guide
===========================

This guide covers general installation, using
the standalone ``taurex`` program and the library

.. toctree::
    :maxdepth: 2

    Introduction <introduction>
    Installation <installation>
    MPI <mpi>
    Supported Data Formats <support_data_formats>
    taurex program <taurex/index>
    Plugins <plugins>
    Library <library/index>


* :ref:`genindex`